import logging
from django.apps import AppConfig
import threading
import asyncio

logger = logging.getLogger(__name__)


class ApiConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "api"

    def ready(self):
        """
        Initialize application components when Django starts.
        This will start the socket monitoring service in a separate thread.
        """
        # Skip when running management commands to avoid double initialization
        import sys

        cmd = " ".join(sys.argv)

        if not any(word in cmd for word in ("runserver", "uvicorn", "gunicorn", "daphne", "hypercorn")):
            return

        logger.info("Initializing API application components")

        # Start socket monitor in a background thread
        thread = threading.Thread(target=self._start_socket_monitor, daemon=True)
        thread.start()

        logger.info("Socket monitor thread started")

    def _start_socket_monitor(self):
        """
        Start the socket monitor in an asyncio event loop.
        This runs in a separate thread.
        """
        try:
            from .services import SocketMonitorService

            # Create new event loop for this thread
            loop = asyncio.new_event_loop()
            asyncio.set_event_loop(loop)

            # Get socket monitor instance
            socket_monitor = SocketMonitorService.get_instance()

            # Start monitoring
            logger.info("Starting socket monitor...")
            loop.run_until_complete(socket_monitor.start_monitoring())

            # Keep the loop running
            logger.info("Socket monitor started, running event loop")
            loop.run_forever()
        except Exception as e:
            logger.error(f"Error starting socket monitor: {e}", exc_info=True)
